---
title: "Gouldian Finch"
format:
  html:
    toc: true
    toc-depth: 2
    number-sections: true
    toc-location: left
    fig-cap-location: top
    code-fold: false
    code-tools: true
    theme: flatly
    page-layout: full
editor: visual

vignette: >
  %\VignetteIndexEntry{Gouldian Finch}
  %\VignetteEngine{quarto::html}
  %\VignetteEncoding{UTF-8}
---

```{r, echo=FALSE, message=FALSE, warning=FALSE}
# Ensure the temporary library from R CMD check is visible (esp. on Windows)
libdir <- Sys.getenv("R_LIBS")
if (nzchar(libdir)) {
  parts <- strsplit(libdir, .Platform$path.sep, fixed = TRUE)[[1]]
  .libPaths(unique(c(parts, .libPaths())))
}

# now load your package
suppressPackageStartupMessages(library(ecotourism))
```

::: {style="text-align:center"}
![](image/gouldian_finch.jpg){width="300"}

[Photo by Kym Nicolson. Licensed under [CC BY 4.0](https://creativecommons.org/licenses/by/4.0/).]{style="font-size: 50%; align: center; margin-top:0.02em;"}
:::

## Introduction

This vignette demonstrates how to **analyze occurrence data for Gouldian Finch in Australia**, using records from the [Atlas of Living Australia (ALA)](https://www.ala.org.au/).

The dataset has been prepared for you to explore, making it suitable for both study and practice with real-world ecological data. In this vignette we provide short examples of how to manipulate and visualize the dataset, but you are encouraged to develop your own creative approaches for analysis and visualization.

This is the glimpse of your data :

```{r, echo=TRUE, eval=TRUE, message=FALSE, warning=FALSE}
library(dplyr)
library(ecotourism)
data("gouldian_finch")
gouldian_finch |> glimpse()
```

------------------------------------------------------------------------

## Visualization

### Spatial Distribution Map

Distribution of Occurrence Gouldian Finch Sightings in Australia

```{r echo=TRUE, fig.width=6, fig.height=4, eval=TRUE}
library(ggplot2)
library(ggthemes)

gouldian_finch |> 
  ggplot() +
    geom_sf(data = oz_lga) +
    geom_point(aes(x = obs_lon, y = obs_lat), color = "red") +
    theme_map()
```

Keep in mind that the natural range of the **Gouldian Finch** is in northern Australia. Occasional records from the south may reflect birds in captivity, such as those observed in zoos, rather than wild populations.

------------------------------------------------------------------------

## Weekly, Monthly, and Yearly Trends

Weekday Distribution of Gouldian Finch Sightings

```{r echo=TRUE, fig.width=6, fig.height=4, eval=TRUE}
week_order <- c("Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday", "Sunday")

gouldian_finch |> 
  ggplot(aes(x = factor(weekday, levels = week_order))) +
    geom_bar() +
    labs(x = "Weekday", y = "Number of Records") +
    theme_minimal()
```

Monthly Distribution of Gouldian Finch Sightings

```{r echo=TRUE, fig.width=6, fig.height=4, eval=TRUE, message=FALSE, warning=FALSE}
library(lubridate)

gouldian_finch |>
    dplyr::mutate(month = month(month, label = TRUE, abbr = TRUE)) |>
    ggplot(aes(x = factor(month))) +
    geom_bar() +
    labs(x = "Month", y = "Number of Records") +
    theme_minimal()
```

Yearly Distribution of Gouldian Finch Sightings

```{r echo=TRUE, fig.width=6, fig.height=4, eval=TRUE}
gouldian_finch |>
    ggplot(aes(x = factor(year))) +
    geom_bar() +
    labs(x = "Year", y = "Number of Records")+
    theme_minimal()
```

------------------------------------------------------------------------

## Relational visualization 

We want to see if `gouldian_finch` occurrences are related to precipitation on the same day from the weather dataset.

Here’s a short R script that:

1.  Joins `gouldian_finch` with **weather** using `ws_id` and `date`.

2.  Counts daily occurrences.

3.  Plots precipitation vs number of `gouldian_finch` sightings.

```{r, echo=TRUE, eval=TRUE, message=FALSE, warning=FALSE, fig.width=6, fig.height=4}
library(ggbeeswarm)

# Prepare gouldian_finch occurrence counts per day
gouldian_finch_daily <- gouldian_finch |>
  group_by(ws_id, date) |>
  summarise(occurrence = n(), .groups = "drop")

# Join with weather data for precipitation
gouldian_finch_weather <- gouldian_finch_daily |>
  left_join(weather |> select(ws_id, date, prcp), 
            by = c("ws_id", "date"))

gouldian_finch_weather |>
  filter(!is.na(prcp)) |>
  mutate(rain = if_else(prcp > 5, "yes", "no")) |>
  ggplot(aes(x = rain, y = occurrence)) +
  geom_quasirandom(alpha = 0.6) +
  ylim(c(0, 15)) +
  labs(
    title = "Relationship between rainy day and gouldian finch occurrence",
    x = "Rainy",
    y = "Number of Gouldian Finch records"
  ) +
  theme_minimal()

```


```{r, echo=TRUE, eval=TRUE, message=FALSE, warning=FALSE, fig.width=6, fig.height=4}

gouldian_finch_weather <- gouldian_finch_daily |> 
  left_join(
    weather |> select(ws_id, date, temp, prcp),
    by = c("ws_id", "date")
  )


ggplot(gouldian_finch_weather, aes(temp, occurrence, color = prcp)) +
  geom_point(alpha = 0.5) +
  scale_color_viridis_c() +
  labs(
    title = "Gouldian Finch occurrence vs temperature, colored by precipitation",
    x = "Mean daily temperature (°C)",
    y = "Occurrences",
    color = "Precipitation (mm)"
  ) +
  theme_minimal()


```
